| Title: | Variational Bayesian Analysis of Survival Data |
|---|---|
| Description: | Implements Bayesian inference in accelerated failure time (AFT) models for right-censored survival times assuming a log-logistic distribution. Details of the variational Bayes algorithms, with and without shared frailty, are described in Xian et al. (2024) <doi:10.1007/s11222-023-10365-6> and Xian et al. (2024) <doi:10.48550/arXiv.2408.00177>, respectively. |
| Authors: | Alison Zhang [aut, cre], Chengqian Xian [aut] |
| Maintainer: | Alison Zhang <[email protected]> |
| License: | MIT + file LICENSE | LGPL-2 |
| Version: | 0.0.2 |
| Built: | 2026-05-31 07:31:10 UTC |
| Source: | https://github.com/chengqianxian/survregvb |
of to optimize the
evidence based lower bound (ELBO) in survregVB.fit and
survregVB.frailty.fit.Calculates parameter of to optimize the
evidence based lower bound (ELBO) in survregVB.fit and
survregVB.frailty.fit.
alpha_star(alpha_0, delta)alpha_star(alpha_0, delta)
alpha_0 |
The shape hyperparameter |
delta |
A binary vector indicating right censoring. |
Parameter of .
rhDNase from the survival packageThe dnase dataset is a subset of the rhDNase dataset from the
survival package.
It is included in this package under the LGPL () license.
dnasednase
A data frame with 767 observations on the following variables:
treatment arm: 0=placebo, 1= rhDNase
forced expriatory volume at enrollment, a measure of lung capacity
an infection that required the use of intravenous antibiotics
difference between the date of entry into the study and the date of last follow-up capped at 169 days
survival package.
https://cran.r-project.org/package=survival
survregVB.fit.Calculates the variational Bayes convergence criteria, evidence lower
bound (ELBO), optimized in survregVB.fit.
elbo( y, X, delta, alpha_0, omega_0, mu_0, v_0, alpha, omega, mu, Sigma, expectation_b )elbo( y, X, delta, alpha_0, omega_0, mu_0, v_0, alpha, omega, mu, Sigma, expectation_b )
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
alpha_0 |
The shape hyperparameter |
omega_0 |
The shape hyperparameter |
mu_0 |
Hyperparameter |
v_0 |
The precision (inverse variance) hyperparameter |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
Sigma |
Parameter |
expectation_b |
The expected value of b. |
survregVB.frailty.fit.Calculates the variational Bayes convergence criteria, evidence lower
bound (ELBO), optimized in survregVB.frailty.fit.
elbo_cluster( y, X, delta, alpha_0, omega_0, mu_0, v_0, lambda_0, eta_0, alpha, omega, mu, Sigma, tau, sigma, lambda, eta, expectation_b, cluster )elbo_cluster( y, X, delta, alpha_0, omega_0, mu_0, v_0, lambda_0, eta_0, alpha, omega, mu, Sigma, tau, sigma, lambda, eta, expectation_b, cluster )
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
alpha_0 |
The shape hyperparameter |
omega_0 |
The shape hyperparameter |
mu_0 |
Hyperparameter |
v_0 |
The precision (inverse variance) hyperparameter |
lambda_0 |
The shape hyperparameter |
eta_0 |
The scale hyperparameter |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
Sigma |
Parameter |
tau |
Parameter |
sigma |
Parameter |
lambda |
The shape parameter |
eta |
The scale parameter |
expectation_b |
The expected value of b. |
cluster |
A numeric vector indicating the cluster assignment for each observation. |
The evidence lower bound (ELBO).
of to
optimize the evidence based lower bound (ELBO) in
survregVB.frailty.fit.Calculates parameter of to
optimize the evidence based lower bound (ELBO) in
survregVB.frailty.fit.
eta_star(eta_0, tau, sigma)eta_star(eta_0, tau, sigma)
eta_0 |
The scale hyperparameter |
tau |
Parameter |
sigma |
Parameter |
Parameter of .
of to
optimize the evidence based lower bound (ELBO) in
survregVB.frailty.fit.Calculates parameter of to
optimize the evidence based lower bound (ELBO) in
survregVB.frailty.fit.
lambda_star(lambda_0, K)lambda_star(lambda_0, K)
lambda_0 |
The shape hyperparameter |
K |
The number of clusters. |
Parameter of .
This dataset is a subset of the GSE102287 dataset that includes only characteristics of patients who are identified as African American (AA).
lung_cancerlung_cancer
A data frame with 60 observations on selected patient characteristics:
Patient identification number.
Patient age.
Lung cancer stage (I, II, III).
Survival time in days.
Gender of the patient.
0 = Never smoked, 1 = Has smoked.
0 = Alive, 1 = Death due to lung cancer.
Gene Expression Omnibus (GEO), Accession: GSE102287. https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE102287
Mitchell, K. A., Zingone, A., Toulabi, L., Boeckelman, J., & Ryan, B. M. (2017). Comparative Transcriptome Profiling Reveals Coding and Noncoding RNA Differences in NSCLC from African Americans and European Americans. Clinical cancer research: an official journal of the American Association for Cancer Research, 23(23), 7412–7425. doi:10.1158/1078-0432.CCR-17-0527.
of to optimize the
evidence based lower bound (ELBO) in survregVB.fit.Calculates parameter of to optimize the
evidence based lower bound (ELBO) in survregVB.fit.
mu_star(y, X, delta, mu_0, v_0, alpha, omega, mu, Sigma, expectation_b)mu_star(y, X, delta, mu_0, v_0, alpha, omega, mu, Sigma, expectation_b)
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
mu_0 |
Hyperparameter |
v_0 |
The precision (inverse variance) hyperparameter |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
Sigma |
Parameter |
expectation_b |
The expected value of b. |
Parameter of .
of to optimize the
evidence based lower bound (ELBO) in survregVB.frailty.fit.Calculates parameter of to optimize the
evidence based lower bound (ELBO) in survregVB.frailty.fit.
mu_star_cluster( y, X, delta, mu_0, v_0, alpha, omega, mu, Sigma, tau, expectation_b, cluster )mu_star_cluster( y, X, delta, mu_0, v_0, alpha, omega, mu, Sigma, tau, expectation_b, cluster )
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
mu_0 |
Hyperparameter |
v_0 |
The precision (inverse variance) hyperparameter |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
Sigma |
Parameter |
tau |
Parameter |
expectation_b |
The expected value of b. |
cluster |
A numeric vector indicating the cluster assignment for each observation. |
Parameter of
of to optimize the
evidence based lower bound (ELBO) in survregVB.fit.Calculates parameter of to optimize the
evidence based lower bound (ELBO) in survregVB.fit.
omega_star(y, X, delta, omega_0, mu, expectation_b)omega_star(y, X, delta, omega_0, mu, expectation_b)
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
omega_0 |
The shape hyperparameter |
mu |
Parameter |
expectation_b |
The expected value of b. |
Parameter of .
of to optimize the evidence
based lower bound (ELBO) in survregVB.frailty.fit.Calculates parameter of to optimize the evidence
based lower bound (ELBO) in survregVB.frailty.fit.
omega_star_cluster(y, X, delta, omega_0, mu, tau, expectation_b, cluster)omega_star_cluster(y, X, delta, omega_0, mu, tau, expectation_b, cluster)
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
omega_0 |
The shape hyperparameter |
mu |
Parameter |
tau |
Parameter |
expectation_b |
The expected value of b. |
cluster |
A numeric vector indicating the cluster assignment for each observation. |
Parameter of .
of for
clusters to optimize the evidence based lower bound
(ELBO) in survregVB.frailty.fit.Calculates parameter of for
clusters to optimize the evidence based lower bound
(ELBO) in survregVB.frailty.fit.
sigma_squared_star( y, X, delta, alpha, omega, mu, tau, lambda, eta, expectation_b, cluster )sigma_squared_star( y, X, delta, alpha, omega, mu, tau, lambda, eta, expectation_b, cluster )
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
tau |
Parameter |
lambda |
The shape parameter |
eta |
The scale parameter |
expectation_b |
The expected value of b. |
cluster |
A numeric vector indicating the cluster assignment for each observation. |
Parameter vector of
for all clusters.
of to optimize the
evidence based lower bound (ELBO) in survregVB.fit.Calculates parameter of to optimize the
evidence based lower bound (ELBO) in survregVB.fit.
Sigma_star(y, X, delta, v_0, alpha, omega, mu, expectation_b)Sigma_star(y, X, delta, v_0, alpha, omega, mu, expectation_b)
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
v_0 |
The precision (inverse variance) hyperparameter |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
expectation_b |
The expected value of b. |
Parameter of .
of to optimize the
evidence based lower bound (ELBO) in survregVB.frailty.fit.Calculates parameter of to optimize the
evidence based lower bound (ELBO) in survregVB.frailty.fit.
Sigma_star_cluster( y, X, delta, v_0, alpha, omega, mu, tau, expectation_b, cluster )Sigma_star_cluster( y, X, delta, v_0, alpha, omega, mu, tau, expectation_b, cluster )
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
v_0 |
The precision (inverse variance) hyperparameter |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
tau |
Parameter |
expectation_b |
The expected value of b. |
cluster |
A numeric vector indicating the cluster assignment for each observation. |
Parameter of .
Simulated data incorporating shared frailty effects to model clustered time-to-event data.
simulation_frailtysimulation_frailty
A dataframe with 75 observations grouped into 15 clusters, each with 5 individuals.
Continuous covariate from N(1, 0.2^2)
Binary covariate from Bernoulli(0.5)
True survival time
Observed survival time accounting for uniformly distributed
right censoring time from uniform(0,u)
Event indicator for uncensored data (always 1 in this simulation.)
Event indicator after censoring (1 = event, 0 = censored).
Cluster ID (1–15), indicating group-level frailty
. @references Xian, C., Souza, C. P. E. de, He, W., Rodrigues, F. F., & Tian, R. (2024). Fast variational bayesian inference for correlated survival data: An application to invasive mechanical ventilation duration analysis. https://doi.org/10.48550/ARXIV.2408.00177
Simulated data without shared frailty effects to model unclustered time-to-event data.
simulation_nofrailtysimulation_nofrailty
A dataframe with 300 observations.
Continuous covariate from N(1, 0.2^2)
Binary covariate from Bernoulli(0.5)
True survival time
Observed survival time accounting for uniformly distributed
right censoring time from uniform(0,48)
Observed survival time accounting for uniformly distributed
right censoring time from uniform(0,17)
Event indicator for uncensored data (always 1 in this simulation.)
Event indicator for T.10 (1 = event, 0 = censored).
Event indicator for T.30 (1 = event, 0 = censored).
@references Xian, C., Souza, C. P. E. de, He, W., Rodrigues, F. F., & Tian, R. (2024). Variational Bayesian analysis of survival data using a log-logistic accelerated failure time model. Statistics and Computing, 34(2). https://doi.org/10.1007/s11222-023-10365-6
Produces a summary of a fitted Variational Bayes Parametric Survival Regression Model for a Log-Logistic AFT Model
## S3 method for class 'survregVB' summary(object, ci = 0.95, ...)## S3 method for class 'survregVB' summary(object, ci = 0.95, ...)
object |
The result of a |
ci |
The significance level for the credible intervals. (Default:0.95). |
... |
For future arguments. |
An object of class summary.survregVB with components:
ELBO: The final value of the Evidence Lower Bound (ELBO)
at the last iteration.
alpha: The shape parameter of .
omega: The scale parameter of .
mu: Parameter of , a vector
of means.
Sigma: Parameter of , a
covariance matrix.
na.action: A missing-data filter function, applied to the
model.frame, after any subset argument has been used.
iterations: The number of iterations performed by the VB
algorithm: before converging or reaching max_iteration.
n: The number of observations.
call: The function call used to invoke the survregVB
method.
not_converged: A boolean indicating if the algorithm
converged.
TRUE: If the algorithm did not converge prior to
achieving max_iteration.
NULL: If the algorithm converged successfully.
estimates: A matrix with one row for each regression coefficient,
and one row for the scale parameter. The columns contain:
Value: The estimated value based on the posterior
distribution mean.
Lower CI: The lower bound of the credible interval.
Upper CI: The upper bound of the credible interval.
If called with shared frailty, the object also contains components:
lambda: The shape parameter of
.
eta: The scale parameter of
.
tau: Parameter of , a
vector of means.
sigma: Parameter of ,
a vector of variance.
The estimates component will contain an additional row for the
frailty, the estimated variance based on the posterior mean for the
random intercepts.
Applies a mean-field Variational Bayes (VB) algorithm to infer the parameters of an accelerated failure time (AFT) survival model with right-censored survival times following a log-logistic distribution.
survregVB( formula, data, alpha_0, omega_0, mu_0, v_0, lambda_0, eta_0, na.action, cluster, max_iteration = 100, threshold = 1e-04 )survregVB( formula, data, alpha_0, omega_0, mu_0, v_0, lambda_0, eta_0, na.action, cluster, max_iteration = 100, threshold = 1e-04 )
formula |
A formula object, with the response on the left of a |
data |
A |
alpha_0 |
The shape hyperparameter |
omega_0 |
The shape hyperparameter |
mu_0 |
Hyperparameter |
v_0 |
The precision (inverse variance) hyperparameter |
lambda_0 |
The shape hyperparameter |
eta_0 |
The scale hyperparameter |
na.action |
A missing-data filter function, applied to the
|
cluster |
An optional variable which clusters the observations to introduce shared frailty for correlated survival data. |
max_iteration |
The maximum number of iterations for the variational inference optimization. If reached, iteration stops. (Default:100) |
threshold |
The convergence threshold for the evidence based lower bound (ELBO) optimization. If the difference between the current and previous ELBO's is smaller than this threshold, iteration stops. (Default:0.0001) |
The goal of survregVB is to maximize the evidence lower bound
(ELBO) to approximate posterior distributions of the AFT model parameters
using the VB algorithms with and without shared frailty proposed in Xian
et al. (2024) https://doi.org/10.1007/s11222-023-10365-6 and
https://doi.org/10.48550/ARXIV.2408.00177 respectively.
An object of class survregVB.
Xian, C., Souza, C. P. E. de, He, W., Rodrigues, F. F., & Tian, R. (2024). "Variational Bayesian analysis of survival data using a log-logistic accelerated failure time model." Statistics and Computing, 34(2). https://doi.org/10.1007/s11222-023-10365-6
Xian, C., Souza, C. P. E. de, He, W., Rodrigues, F. F., & Tian, R. (2024). "Fast variational bayesian inference for correlated survival data: An application to invasive mechanical ventilation duration analysis." https://doi.org/10.48550/ARXIV.2408.00177
# Data frame containing survival data fit <- survregVB( formula = survival::Surv(time, infect) ~ trt + fev, data = dnase, alpha_0 = 501, omega_0 = 500, mu_0 = c(4.4, 0.25, 0.04), v_0 = 1, max_iteration = 100, threshold = 0.0005 ) summary(fit) # Call the survregVB function with shared frailty fit2 <- survregVB( formula = survival::Surv(Time.15, delta.15) ~ x1 + x2, data = simulation_frailty, alpha_0 = 3, omega_0 = 2, mu_0 = c(0, 0, 0), v_0 = 0.1, lambda_0 = 3, eta_0 = 2, cluster = cluster, max_iteration = 100, threshold = 0.01 ) summary(fit2)# Data frame containing survival data fit <- survregVB( formula = survival::Surv(time, infect) ~ trt + fev, data = dnase, alpha_0 = 501, omega_0 = 500, mu_0 = c(4.4, 0.25, 0.04), v_0 = 1, max_iteration = 100, threshold = 0.0005 ) summary(fit) # Call the survregVB function with shared frailty fit2 <- survregVB( formula = survival::Surv(Time.15, delta.15) ~ x1 + x2, data = simulation_frailty, alpha_0 = 3, omega_0 = 2, mu_0 = c(0, 0, 0), v_0 = 0.1, lambda_0 = 3, eta_0 = 2, cluster = cluster, max_iteration = 100, threshold = 0.01 ) summary(fit2)
Called by survregVB to do the actual parameter and ELBO
computations. This routine does no checking that the arguments are the
proper length or type.
survregVB.fit( Y, X, alpha_0, omega_0, mu_0, v_0, max_iteration = 100, threshold = 1e-04 )survregVB.fit( Y, X, alpha_0, omega_0, mu_0, v_0, max_iteration = 100, threshold = 1e-04 )
Y |
A |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
alpha_0 |
The shape hyperparameter |
omega_0 |
The shape hyperparameter |
mu_0 |
Hyperparameter |
v_0 |
The precision (inverse variance) hyperparameter |
max_iteration |
The maximum number of iterations for the variational inference optimization. If reached, iteration stops. (Default:100) |
threshold |
The convergence threshold for the evidence based lower bound (ELBO) optimization. If the difference between the current and previous ELBO's is smaller than this threshold, iteration stops. (Default:0.0001) |
Implements the Variational Bayes algorithm proposed in the paper "Variational Bayesian analysis of survival data using a log-logistic accelerated failure time model."
For right-censored survival time of the subject
in a sample, , the log-logistic AFT model is specified
as follows:
, where
is a column vector of length containing
covariates and a constant one to incorporate the intercept
(i.e., ),
is the corresponding vector of coefficients for the fixed
effects,
is a random variable following a standard logistic
distribution, and
b is a scale parameter.
A list containing results of the fit.
Xian, C., Souza, C. P. E. de, He, W., Rodrigues, F. F., & Tian, R. (2024). "Variational Bayesian analysis of survival data using a log-logistic accelerated failure time model." Statistics and Computing, 34(2). https://doi.org/10.1007/s11222-023-10365-6
fit <- survregVB.fit( Y = survival::Surv(simulation_nofrailty$Time, simulation_nofrailty$delta), X = matrix(c(rep(1, 300), simulation_nofrailty$x1, simulation_nofrailty$x2), nrow = 300), alpha_0 = 11, omega_0 = 10, mu_0 = c(0, 0, 0), v_0 = 1 )fit <- survregVB.fit( Y = survival::Surv(simulation_nofrailty$Time, simulation_nofrailty$delta), X = matrix(c(rep(1, 300), simulation_nofrailty$x1, simulation_nofrailty$x2), nrow = 300), alpha_0 = 11, omega_0 = 10, mu_0 = c(0, 0, 0), v_0 = 1 )
Called by survregVB to do the actual parameter and ELBO computations
for correlated survival data with shared frailty (a random intercept).
This routine does no checking that the arguments are the proper length
or type.
survregVB.frailty.fit( Y, X, alpha_0, omega_0, mu_0, v_0, lambda_0, eta_0, cluster, max_iteration = 100, threshold = 1e-04 )survregVB.frailty.fit( Y, X, alpha_0, omega_0, mu_0, v_0, lambda_0, eta_0, cluster, max_iteration = 100, threshold = 1e-04 )
Y |
A |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
alpha_0 |
The shape hyperparameter |
omega_0 |
The shape hyperparameter |
mu_0 |
Hyperparameter |
v_0 |
The precision (inverse variance) hyperparameter |
lambda_0 |
The shape hyperparameter |
eta_0 |
The scale hyperparameter |
cluster |
An optional variable which clusters the observations to introduce shared frailty for correlated survival data. |
max_iteration |
The maximum number of iterations for the variational inference optimization. If reached, iteration stops. (Default:100) |
threshold |
The convergence threshold for the evidence based lower bound (ELBO) optimization. If the difference between the current and previous ELBO's is smaller than this threshold, iteration stops. (Default:0.0001) |
Implements the Variational Bayes algorithm with random intercepts proposed in the paper "Fast variational bayesian inference for correlated survival data: An application to invasive mechanical ventilation duration analysis".
For right-censored survival time of the subject
from the cluster in the sample, in a sample,
and , the shared-frailty log-logistic AFT model is specified
as follows:
, where
is a column vector of length containing
covariates and a constant one to incorporate the intercept
(i.e., ),
is the corresponding vector of coefficients for the fixed effects,
is a random intercept for the cluster,
is a random variable following a standard logistic
distribution, and
b is a scale parameter.
A list containing results of the fit.
Xian, C., Souza, C. P. E. de, He, W., Rodrigues, F. F., & Tian, R. (2024). "Fast variational bayesian inference for correlated survival data: An application to invasive mechanical ventilation duration analysis." https://doi.org/10.48550/ARXIV.2408.00177
fit <- survregVB.frailty.fit( X = matrix(c(rep(1, 75), simulation_frailty$x1, simulation_frailty$x2), nrow = 75), Y = survival::Surv(simulation_frailty$Time, simulation_frailty$delta), alpha_0 = 3, omega_0 = 2, mu_0 = c(0, 0, 0), v_0 = 0.1, lambda_0 = 3, eta_0 = 2, cluster = simulation_frailty$cluster )fit <- survregVB.frailty.fit( X = matrix(c(rep(1, 75), simulation_frailty$x1, simulation_frailty$x2), nrow = 75), Y = survival::Surv(simulation_frailty$Time, simulation_frailty$delta), alpha_0 = 3, omega_0 = 2, mu_0 = c(0, 0, 0), v_0 = 0.1, lambda_0 = 3, eta_0 = 2, cluster = simulation_frailty$cluster )
This class of objects is returned by the survregVB function to represent
a fitted parametric log-logistic accelerated failure time (AFT) survival
model. Objects of this class have methods for the functions print
and summary.
For approximate posterior distributions:
, a density function, and
, an
density function,
the components of this class are:
ELBO: The final value of the Evidence Lower Bound (ELBO)
at the last iteration.
alpha: The shape parameter of .
omega: The scale parameter of .
mu: Parameter of , a vector
of means.
Sigma: Parameter of , a
covariance matrix.
na.action: A missing-data filter function, applied to the
model.frame, after any subset argument has been used.
iterations: The number of iterations performed by the VB
algorithm: before converging or reaching max_iteration.
n: The number of observations.
call: The function call used to invoke the survregVB
method.
not_converged: A boolean indicating if the algorithm
converged.
TRUE: If the algorithm did not converge prior to
achieving max_iteration.
NULL: If the algorithm converged successfully.
If survregVB was called with shared frailty (with the cluster
argument), for approximate posterior distributions:
, an
density function,
, a density function,
for clusters, and
the additional components are present:
lambda: The shape parameter of
.
eta: The scale parameter of
.
tau: Parameter of , a
vector of means.
sigma: Parameter of ,
a vector of variance.
of for
clusters to optimize the evidence based lower bound
(ELBO) in survregVB.frailty.fit.Calculates parameter of for
clusters to optimize the evidence based lower bound
(ELBO) in survregVB.frailty.fit.
tau_star(y, X, delta, alpha, omega, mu, tau, sigma, expectation_b, cluster)tau_star(y, X, delta, alpha, omega, mu, tau, sigma, expectation_b, cluster)
y |
A vector of observed log-transformed survival times. |
X |
A design matrix including covariates with first column of ones to represent the intercept. |
delta |
A binary vector indicating right censoring. |
alpha |
The shape parameter |
omega |
The scale parameter |
mu |
Parameter |
tau |
Parameter |
sigma |
Parameter |
expectation_b |
The expected value of b. |
cluster |
A numeric vector indicating the cluster assignment for each observation. |
Parameter vector of for
clusters.